Simplifier

Struct Simplifier 

pub struct Simplifier<T: ExprMap<Option<ExprRef>>> { /* private fields */ }
Performs simplification and canonicalization on expressions and caches the results.

Implementations

Source

impl<T: ExprMap<Option<ExprRef>>> Simplifier<T>

pub fn new(cache: T) -> Self

pub fn simplify(&mut self, ctx: &mut Context, e: ExprRef) -> ExprRef

pub fn verify_simplification( &self, ctx: &mut Context, solver: &mut impl SolverContext, ) -> Result<usize>

Uses an SMT solver to check all simplification steps that have been made with this Simplifier. Returns the number of incorrect simplifications.